==> cscec5bhn-wzxt-api-3.0.1-20220827.111059-66-sources.jar: com/ejianc/business/wzxt/vo/DeliveryDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 发货实体明细表
 *
 * @author generator
 *
 */
public class DeliveryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long deliveryId; // 发货主键ID
    private Long orderId; // 订单主键ID
    private Long orderDetailId; // 订单明细主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal receiveNumsSum; // 接收数量
    private java.math.BigDecimal orderNumsSum; // 订单数量
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal unDeliverNumsSum; // 发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private String materialManufacturer; // 生产厂家
    private String memo; // 备注
    private String smartStatus; // 智能称重标识
    private Boolean historyFlag; // 是否历史数据
    private String historyId; // 来源主键
    private String historySystem; // 来源系统
    private java.lang.String materialSourceId; // 物资来源主键
    private java.lang.String def1; // 自定义字段
    private java.lang.String def2; // 自定义字段
    private java.lang.String def3; // 自定义字段
    private java.lang.String def4; // 自定义字段
    private java.lang.String def5; // 自定义字段
    private BigDecimal transformRate;
    private BigDecimal netWeight;
    private java.lang.String orderDetailStringId;

    /******  mro add begin     ******/
    private BigDecimal mroMny; // mro无税金额
    private BigDecimal mroTaxmny; // mro含税金额
    private BigDecimal mroNprice; // mro无税价格
    private BigDecimal mroNtaxprice; // mro含税价格
    private BigDecimal mroTaxrate; // mro税率
    private BigDecimal mroTax; // mro税金
    private BigDecimal mroDeliverNumsSum; // mro发货数量
    private String mroSupplierSkuCode; // 供应商skuCode 字符类型
    private String mroSupplierSkuId; // 供应商skuId长整型
    private Long planDetailId; //需用计划Id
    private BigDecimal mroUnitRatio; // mro换算率
    private String mroUnit; // mro单位

    private java.math.BigDecimal price; // 单价
    private java.math.BigDecimal taxPrice; // 含税单价
    private java.math.BigDecimal taxRate; // 税率

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getMroMny() {
        return mroMny;
    }

    public void setMroMny(BigDecimal mroMny) {
        this.mroMny = mroMny;
    }

    public BigDecimal getMroTaxmny() {
        return mroTaxmny;
    }

    public void setMroTaxmny(BigDecimal mroTaxmny) {
        this.mroTaxmny = mroTaxmny;
    }

    public BigDecimal getMroNprice() {
        return mroNprice;
    }

    public void setMroNprice(BigDecimal mroNprice) {
        this.mroNprice = mroNprice;
    }

    public BigDecimal getMroNtaxprice() {
        return mroNtaxprice;
    }

    public void setMroNtaxprice(BigDecimal mroNtaxprice) {
        this.mroNtaxprice = mroNtaxprice;
    }

    public BigDecimal getMroTaxrate() {
        return mroTaxrate;
    }

    public void setMroTaxrate(BigDecimal mroTaxrate) {
        this.mroTaxrate = mroTaxrate;
    }

    public BigDecimal getMroTax() {
        return mroTax;
    }

    public void setMroTax(BigDecimal mroTax) {
        this.mroTax = mroTax;
    }

    public BigDecimal getMroDeliverNumsSum() {
        return mroDeliverNumsSum;
    }

    public void setMroDeliverNumsSum(BigDecimal mroDeliverNumsSum) {
        this.mroDeliverNumsSum = mroDeliverNumsSum;
    }

    public String getMroSupplierSkuCode() {
        return mroSupplierSkuCode;
    }

    public void setMroSupplierSkuCode(String mroSupplierSkuCode) {
        this.mroSupplierSkuCode = mroSupplierSkuCode;
    }

    public String getMroSupplierSkuId() {
        return mroSupplierSkuId;
    }

    public void setMroSupplierSkuId(String mroSupplierSkuId) {
        this.mroSupplierSkuId = mroSupplierSkuId;
    }

    public Long getPlanDetailId() {
        return planDetailId;
    }

    public void setPlanDetailId(Long planDetailId) {
        this.planDetailId = planDetailId;
    }

    public BigDecimal getMroUnitRatio() {
        return mroUnitRatio;
    }

    public void setMroUnitRatio(BigDecimal mroUnitRatio) {
        this.mroUnitRatio = mroUnitRatio;
    }

    public String getMroUnit() {
        return mroUnit;
    }

    public void setMroUnit(String mroUnit) {
        this.mroUnit = mroUnit;
    }

    /******  mro add end     ******/

    public String getOrderDetailStringId() {
        return orderDetailStringId;
    }

    public void setOrderDetailStringId(String orderDetailStringId) {
        this.orderDetailStringId = orderDetailStringId;
    }

    public BigDecimal getTransformRate() {
        return transformRate;
    }

    public void setTransformRate(BigDecimal transformRate) {
        this.transformRate = transformRate;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public Boolean getHistoryFlag() {
        return historyFlag;
    }

    public void setHistoryFlag(Boolean historyFlag) {
        this.historyFlag = historyFlag;
    }

    public String getHistoryId() {
        return historyId;
    }

    public void setHistoryId(String historyId) {
        this.historyId = historyId;
    }

    public String getHistorySystem() {
        return historySystem;
    }

    public void setHistorySystem(String historySystem) {
        this.historySystem = historySystem;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(String smartStatus) {
        this.smartStatus = smartStatus;
    }
    public BigDecimal getUnDeliverNumsSum() {
        return unDeliverNumsSum;
    }

    public void setUnDeliverNumsSum(BigDecimal unDeliverNumsSum) {
        this.unDeliverNumsSum = unDeliverNumsSum;
    }

    /**
     * 发货主键ID
     */
    public Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 订单主键ID
     */
    public Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 接收数量
     */
    public java.math.BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    /**
     * 接收数量
     */
    public void setReceiveNumsSum(java.math.BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    /**
     * 订单数量
     */
    public void setOrderNumsSum(java.math.BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    @Override
    public String toString() {
        return "DeliveryDetailVO{" +
                "deliveryId=" + deliveryId +
                ", orderId=" + orderId +
                ", orderDetailId=" + orderDetailId +
                ", materialId=" + materialId +
                ", materialName='" + materialName + '\'' +
                ", materialTypeId=" + materialTypeId +
                ", materialTypeName='" + materialTypeName + '\'' +
                ", materialCode='" + materialCode + '\'' +
                ", unit='" + unit + '\'' +
                ", spec='" + spec + '\'' +
                ", receiveNumsSum=" + receiveNumsSum +
                ", orderNumsSum=" + orderNumsSum +
                ", deliverNumsSum=" + deliverNumsSum +
                ", unDeliverNumsSum=" + unDeliverNumsSum +
                ", checkNumsSum=" + checkNumsSum +
                ", materialManufacturer='" + materialManufacturer + '\'' +
                ", memo='" + memo + '\'' +
                ", smartStatus='" + smartStatus + '\'' +
                ", historyFlag=" + historyFlag +
                ", historyId='" + historyId + '\'' +
                ", historySystem='" + historySystem + '\'' +
                ", materialSourceId='" + materialSourceId + '\'' +
                ", def1='" + def1 + '\'' +
                ", def2='" + def2 + '\'' +
                ", def3='" + def3 + '\'' +
                ", def4='" + def4 + '\'' +
                ", def5='" + def5 + '\'' +
                ", transformRate=" + transformRate +
                ", netWeight=" + netWeight +
                ", orderDetailStringId='" + orderDetailStringId + '\'' +
                '}';
    }
}

==> cscec5bhn-wzxt-api-3.0.1-20221024.120220-99-sources.jar: com/ejianc/business/wzxt/vo/DeliveryDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 发货实体明细表
 *
 * @author generator
 *
 */
public class DeliveryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long deliveryId; // 发货主键ID
    private Long orderId; // 订单主键ID
    private Long orderDetailId; // 订单明细主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal receiveNumsSum; // 接收数量
    private java.math.BigDecimal orderNumsSum; // 订单数量
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    private java.math.BigDecimal unDeliverNumsSum; // 发货数量
    private java.math.BigDecimal checkNumsSum; // 验收数量
    private String materialManufacturer; // 生产厂家
    private String memo; // 备注
    private String smartStatus; // 智能称重标识
    private Boolean historyFlag; // 是否历史数据
    private String historyId; // 来源主键
    private String historySystem; // 来源系统
    private java.lang.String materialSourceId; // 物资来源主键
    private java.lang.String def1; // 自定义字段
    private java.lang.String def2; // 自定义字段
    private java.lang.String def3; // 自定义字段
    private java.lang.String def4; // 自定义字段
    private java.lang.String def5; // 自定义字段
    private BigDecimal transformRate;
    private BigDecimal netWeight;
    private java.lang.String orderDetailStringId;

    /******  mro add begin     ******/
    private BigDecimal mroMny; // mro无税金额
    private BigDecimal mroTaxmny; // mro含税金额
    private BigDecimal mroNprice; // mro无税价格
    private BigDecimal mroNtaxprice; // mro含税价格
    private BigDecimal mroTaxrate; // mro税率
    private BigDecimal mroTax; // mro税金
    private BigDecimal mroDeliverNumsSum; // mro发货数量
    private String mroSupplierSkuCode; // 供应商skuCode 字符类型
    private String mroSupplierSkuId; // 供应商skuId长整型
    private Long planDetailId; //需用计划Id
    private BigDecimal mroUnitRatio; // mro换算率
    private String mroUnit; // mro单位

    private java.math.BigDecimal price; // 单价
    private java.math.BigDecimal taxPrice; // 含税单价
    private java.math.BigDecimal taxRate; // 税率

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getMroMny() {
        return mroMny;
    }

    public void setMroMny(BigDecimal mroMny) {
        this.mroMny = mroMny;
    }

    public BigDecimal getMroTaxmny() {
        return mroTaxmny;
    }

    public void setMroTaxmny(BigDecimal mroTaxmny) {
        this.mroTaxmny = mroTaxmny;
    }

    public BigDecimal getMroNprice() {
        return mroNprice;
    }

    public void setMroNprice(BigDecimal mroNprice) {
        this.mroNprice = mroNprice;
    }

    public BigDecimal getMroNtaxprice() {
        return mroNtaxprice;
    }

    public void setMroNtaxprice(BigDecimal mroNtaxprice) {
        this.mroNtaxprice = mroNtaxprice;
    }

    public BigDecimal getMroTaxrate() {
        return mroTaxrate;
    }

    public void setMroTaxrate(BigDecimal mroTaxrate) {
        this.mroTaxrate = mroTaxrate;
    }

    public BigDecimal getMroTax() {
        return mroTax;
    }

    public void setMroTax(BigDecimal mroTax) {
        this.mroTax = mroTax;
    }

    public BigDecimal getMroDeliverNumsSum() {
        return mroDeliverNumsSum;
    }

    public void setMroDeliverNumsSum(BigDecimal mroDeliverNumsSum) {
        this.mroDeliverNumsSum = mroDeliverNumsSum;
    }

    public String getMroSupplierSkuCode() {
        return mroSupplierSkuCode;
    }

    public void setMroSupplierSkuCode(String mroSupplierSkuCode) {
        this.mroSupplierSkuCode = mroSupplierSkuCode;
    }

    public String getMroSupplierSkuId() {
        return mroSupplierSkuId;
    }

    public void setMroSupplierSkuId(String mroSupplierSkuId) {
        this.mroSupplierSkuId = mroSupplierSkuId;
    }

    public Long getPlanDetailId() {
        return planDetailId;
    }

    public void setPlanDetailId(Long planDetailId) {
        this.planDetailId = planDetailId;
    }

    public BigDecimal getMroUnitRatio() {
        return mroUnitRatio;
    }

    public void setMroUnitRatio(BigDecimal mroUnitRatio) {
        this.mroUnitRatio = mroUnitRatio;
    }

    public String getMroUnit() {
        return mroUnit;
    }

    public void setMroUnit(String mroUnit) {
        this.mroUnit = mroUnit;
    }

    /******  mro add end     ******/

    /******  rent add begin     ******/
    private String unitId; // 档案单位主键
    private String unitName; // 档案单位名称
    private String realUnitId; // 实物单位主键
    private String realUnitName; // 实物单位名称
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal realNum; // 实物数量

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    /******  rent add end     ******/

    public String getOrderDetailStringId() {
        return orderDetailStringId;
    }

    public void setOrderDetailStringId(String orderDetailStringId) {
        this.orderDetailStringId = orderDetailStringId;
    }

    public BigDecimal getTransformRate() {
        return transformRate;
    }

    public void setTransformRate(BigDecimal transformRate) {
        this.transformRate = transformRate;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public Boolean getHistoryFlag() {
        return historyFlag;
    }

    public void setHistoryFlag(Boolean historyFlag) {
        this.historyFlag = historyFlag;
    }

    public String getHistoryId() {
        return historyId;
    }

    public void setHistoryId(String historyId) {
        this.historyId = historyId;
    }

    public String getHistorySystem() {
        return historySystem;
    }

    public void setHistorySystem(String historySystem) {
        this.historySystem = historySystem;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(String smartStatus) {
        this.smartStatus = smartStatus;
    }
    public BigDecimal getUnDeliverNumsSum() {
        return unDeliverNumsSum;
    }

    public void setUnDeliverNumsSum(BigDecimal unDeliverNumsSum) {
        this.unDeliverNumsSum = unDeliverNumsSum;
    }

    /**
     * 发货主键ID
     */
    public Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 订单主键ID
     */
    public Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 接收数量
     */
    public java.math.BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    /**
     * 接收数量
     */
    public void setReceiveNumsSum(java.math.BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    /**
     * 订单数量
     */
    public java.math.BigDecimal getOrderNumsSum() {
        return orderNumsSum;
    }

    /**
     * 订单数量
     */
    public void setOrderNumsSum(java.math.BigDecimal orderNumsSum) {
        this.orderNumsSum = orderNumsSum;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    @Override
    public String toString() {
        return "DeliveryDetailVO{" +
                "deliveryId=" + deliveryId +
                ", orderId=" + orderId +
                ", orderDetailId=" + orderDetailId +
                ", materialId=" + materialId +
                ", materialName='" + materialName + '\'' +
                ", materialTypeId=" + materialTypeId +
                ", materialTypeName='" + materialTypeName + '\'' +
                ", materialCode='" + materialCode + '\'' +
                ", unit='" + unit + '\'' +
                ", spec='" + spec + '\'' +
                ", receiveNumsSum=" + receiveNumsSum +
                ", orderNumsSum=" + orderNumsSum +
                ", deliverNumsSum=" + deliverNumsSum +
                ", unDeliverNumsSum=" + unDeliverNumsSum +
                ", checkNumsSum=" + checkNumsSum +
                ", materialManufacturer='" + materialManufacturer + '\'' +
                ", memo='" + memo + '\'' +
                ", smartStatus='" + smartStatus + '\'' +
                ", historyFlag=" + historyFlag +
                ", historyId='" + historyId + '\'' +
                ", historySystem='" + historySystem + '\'' +
                ", materialSourceId='" + materialSourceId + '\'' +
                ", def1='" + def1 + '\'' +
                ", def2='" + def2 + '\'' +
                ", def3='" + def3 + '\'' +
                ", def4='" + def4 + '\'' +
                ", def5='" + def5 + '\'' +
                ", transformRate=" + transformRate +
                ", netWeight=" + netWeight +
                ", orderDetailStringId='" + orderDetailStringId + '\'' +
                '}';
    }
}
